unit FMain;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Buttons, StdCtrls, FileVLit, ComCtrls, ExtCtrls, ShellAPI, Menus, Registry;

type
  TFormMain = class(TForm)
    Panel1: TPanel;
    Panel2: TPanel;
    Panel3: TPanel;
    FileListView: TFileListViewLite;
    FileNameEdit: TFileNameEditLite;
    DirectoryCombo: TDirectoryComboLite;
    BtnList: TSpeedButton;
    BtnReport: TSpeedButton;
    BtnSmall: TSpeedButton;
    BtnBig: TSpeedButton;
    EditPath: TEdit;
    Label1: TLabel;
    ComboBoxPref: TComboBox;
    StatusBar: TStatusBar;
    BtnClone: TSpeedButton;
    Label2: TLabel;
    PopupMenu: TPopupMenu;
    AddBottomItem: TMenuItem;
    RemoveItem: TMenuItem;
    N1: TMenuItem;
    ClearItem: TMenuItem;
    AddTopItem: TMenuItem;
    LoadItem: TMenuItem;
    N2: TMenuItem;
    SaveItem: TMenuItem;
    BtnRefresh: TSpeedButton;
    BtnPrevDir: TSpeedButton;
    procedure BtnViewStyleClick(Sender: TObject);
    procedure FileListViewChange(Sender: TObject; Item: TListItem;
      Change: TItemChange);
    procedure FormResize(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FileListViewAfterRead(Sender: TObject);
    procedure FileListViewMouseUp(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure BtnCloneClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure AddTopItemClick(Sender: TObject);
    procedure AddBottomItemClick(Sender: TObject);
    procedure RemoveItemClick(Sender: TObject);
    procedure ClearItemClick(Sender: TObject);
    procedure ComboBoxPrefChange(Sender: TObject);
    procedure LoadItemClick(Sender: TObject);
    procedure SaveItemClick(Sender: TObject);
    procedure BtnRefreshClick(Sender: TObject);
    procedure BtnPrevDirClick(Sender: TObject);
  private
    Procedure GetObjStat;
  public
    { Public declarations }
  end;

Const
  FavoritesKey = 'Software\Easy Target\Enhanced Folder\Preferites';

var
  FormMain: TFormMain;

implementation

{$R *.DFM}

Procedure TFormMain.GetObjStat;
Var
  N: Integer;
begin
  N := FileListView.SelectedNumber;
  If N = 0 Then
  Begin
    N := FileListView.AllFileNumber;
    StatusBar.Panels[0].Text := 'Objects: ' + IntToStr(N);
  End
  Else StatusBar.Panels[0].Text := 'Selected Objects: ' + IntToStr(N);
  N := FileListView.SelectedSize;
  StatusBar.Panels[1].Text := FormatFloat('###,###,###,###', N) + ' bytes';
end;

procedure TFormMain.FormCreate(Sender: TObject);
begin
  If ParamCount > 1 Then
    If ParamStr(2) = 'SHIFT' Then
      Position := poDefault;
end;

procedure TFormMain.FormShow(Sender: TObject);
Var
  Dir: String;
  S: Integer;
begin
  If ParamCount > 2 Then
  Begin
    S := StrToIntDef(ParamStr(3), 9999);
    If S < 9999 Then Left := S + 50;
  End;
  If ParamCount > 3 Then
  Begin
    S := StrToIntDef(ParamStr(4), 9999);
    If S < 9999 Then Top := S + 50;
  End;
  Width := 519;
  Height := 473;
  If ParamCount > 4 Then
  Begin
    S := StrToIntDef(ParamStr(5), 9999);
    If S < 9999 Then Width := S;
  End;
  If ParamCount > 5 Then
  Begin
    S := StrToIntDef(ParamStr(6), 9999);
    If S < 9999 Then Height := S;
  End;
  If ParamCount > 0 Then
  Begin
    Dir := ParamStr(1);
    If DirectoryExists(Dir) Then FileListView.Directory := Dir;
  End;
  FileListView.ReadEnabled := True;
  FileListView.ReRead;
  LoadItemClick(Sender);
end;

procedure TFormMain.FormResize(Sender: TObject);
Var
  Aux: Integer;
begin
  ComboBoxPref.Width := Width - 282;
  EditPath.Width := Width - 26;
  Aux := Width - 63;
  If Aux > 450 Then BtnClone.Left := Aux;
end;

procedure TFormMain.BtnViewStyleClick(Sender: TObject);
begin
  If TSpeedButton(Sender) = BtnList Then FileListView.ViewIconStyle := visList
  Else If TSpeedButton(Sender) = BtnReport Then FileListView.ViewIconStyle := visReport
  Else If TSpeedButton(Sender) = BtnSmall Then FileListView.ViewIconStyle := visSmallIcon
  Else If TSpeedButton(Sender) = BtnBig Then FileListView.ViewIconStyle := visIcon;
end;

procedure TFormMain.FileListViewAfterRead(Sender: TObject);
begin
  GetObjStat;
end;

procedure TFormMain.FileListViewChange(Sender: TObject; Item: TListItem;
  Change: TItemChange);
begin
  If Item.Selected Then EditPath.Text := FileListView.FileName;
end;

procedure TFormMain.FileListViewMouseUp(Sender: TObject;
  Button: TMouseButton; Shift: TShiftState; X, Y: Integer);
begin
  GetObjStat;
end;

procedure TFormMain.BtnCloneClick(Sender: TObject);
Var
  Par: string;
begin
  Par := FileListView.Directory + ' SHIFT ' + IntToStr(Left) + ' ' +
                                              IntToStr(Top) + ' ' +
                                              IntToStr(Width) + ' ' +
                                              IntToStr(Height);
  ShellExecute(Handle, PChar('Open'), PChar(ParamStr(0)), PChar(Par), PChar(''), SW_SHOW);
end;

procedure TFormMain.AddTopItemClick(Sender: TObject);
begin
  ComboBoxPref.Items.Insert(0, FileListView.Directory);
  ComboBoxPref.ItemIndex := 0;
  RemoveItem.Enabled := (ComboBoxPref.Items.Count > 0);
end;

procedure TFormMain.AddBottomItemClick(Sender: TObject);
begin
  ComboBoxPref.Items.Add(FileListView.Directory);
  ComboBoxPref.ItemIndex := ComboBoxPref.Items.Count - 1;
  RemoveItem.Enabled := (ComboBoxPref.Items.Count > 0);
end;

procedure TFormMain.RemoveItemClick(Sender: TObject);
begin
  If ComboBoxPref.ItemIndex = -1 Then Exit;
  ComboBoxPref.Items.Delete(ComboBoxPref.ItemIndex);
  ComboBoxPref.ItemIndex := ComboBoxPref.Items.Count - 1;
  RemoveItem.Enabled := (ComboBoxPref.Items.Count > 0);
end;

procedure TFormMain.ClearItemClick(Sender: TObject);
begin
  ComboBoxPref.Items.Clear;
  RemoveItem.Enabled := (ComboBoxPref.Items.Count > 0);
end;

procedure TFormMain.ComboBoxPrefChange(Sender: TObject);
begin
  If ComboBoxPref.ItemIndex = -1 Then Exit;
  FileListView.Directory := ComboBoxPref.Items[ComboBoxPref.ItemIndex];
end;

procedure TFormMain.LoadItemClick(Sender: TObject);
Var
  Reg: TRegistry;
  Cs: String;
  I, C: Integer;
begin
  ComboBoxPref.Items.Clear;
  Reg := TRegistry.Create;
  If Reg.OpenKey(FavoritesKey, False) Then
  Begin
    Try
      C := Reg.ReadInteger('Count');
    Except
      C := 0;
    End;
    For I := 0 To C Do
    Try
      Cs := Reg.ReadString(IntToStr(I));
      ComboBoxPref.Items.Add(Cs);
    Except
    End;
  End;
  Reg.Free;
end;

procedure TFormMain.SaveItemClick(Sender: TObject);
Var
  Reg: TRegistry;
  Cs: String;
  I, C: Integer;
begin
  Reg := TRegistry.Create;
  Reg.DeleteKey(FavoritesKey);
  If Reg.OpenKey(FavoritesKey, True) Then
  Begin
    Try
      C := ComboBoxPref.Items.Count - 1;
      Reg.WriteInteger('Count', C);
    Except
      ShowMessage('Save Failure!');
      Exit;
    End;
    For I := 0 To C Do
    Try
      Cs := ComboBoxPref.Items[I];
      Reg.WriteString(IntToStr(I), Cs);
    Except
      ShowMessage('Save Failure!');
      Exit;
    End;
  End;
  Reg.Free;
end;

procedure TFormMain.BtnRefreshClick(Sender: TObject);
begin
  FileListView.ReRead;
end;

procedure TFormMain.BtnPrevDirClick(Sender: TObject);
begin
  FileListView.PrevDirectory;
end;

end.
